--# selene: allow(unused_variable)
---@diagnostic disable: unused-local

-- Remove an existing mapping. Examples: >
--
--    vim.keymap.del('n', 'lhs')
--
--    vim.keymap.del({'n', 'i', 'v'}, '<leader>w', { buffer = 5 })
--
-- <
--- @param opts any #table A table of optional arguments:
---             • buffer: (number or boolean) Remove a mapping
---               from the given buffer. When "true" or 0, use the
---               current buffer.
function vim.keymap.del(modes, lhs, opts) end

-- Add a new |mapping|. Examples: >
--
--    -- Can add mapping to Lua functions
--    vim.keymap.set('n', 'lhs', function() print("real lua function") end)
--
--    -- Can use it to map multiple modes
--    vim.keymap.set({'n', 'v'}, '<leader>lr', vim.lsp.buf.references, { buffer=true })
--
--    -- Can add mapping for specific buffer
--    vim.keymap.set('n', '<leader>w', "<cmd>w<cr>", { silent = true, buffer = 5 })
--
--    -- Expr mappings
--    vim.keymap.set('i', '<Tab>', function()
--      return vim.fn.pumvisible() == 1 and "<C-n>" or "<Tab>"
--    end, { expr = true })
--    -- <Plug> mappings
--    vim.keymap.set('n', '[%', '<Plug>(MatchitNormalMultiBackward)')
--
-- <
--- @param mode any #string|table Same mode short names as
---             |nvim_set_keymap()|. Can also be list of modes to
---             create mapping on multiple modes.
--- @param lhs any #string Left-hand side |{lhs}| of the mapping.
--- @param rhs any #string|function Right-hand side |{rhs}| of the
---             mapping. Can also be a Lua function. If a Lua
---             function and `opts.expr == true`, returning `nil`
---             is equivalent to an empty string.
--- @param opts any #table A table of |:map-arguments| such as
---             "silent". In addition to the options listed in
---             |nvim_set_keymap()|, this table also accepts the
---             following keys:
---             • buffer: (number or boolean) Add a mapping to the
---               given buffer. When "true" or 0, use the current
---               buffer.
---             • replace_keycodes: (boolean, default true) When
---               both this and expr is "true",
---               |nvim_replace_termcodes()| is applied to the
---               result of Lua expr maps.
---             • remap: (boolean) Make the mapping recursive.
---               This is the inverse of the "noremap" option from
---               |nvim_set_keymap()|. Default `false`.
function vim.keymap.set(mode, lhs, rhs, opts) end

